Index: wp-login.php
===================================================================
--- wp-login.php	(revision 10289)
+++ wp-login.php	(working copy)
@@ -106,7 +106,7 @@
 			$errors->add('invalid_email', __('<strong>ERROR</strong>: There is no user registered with that email address.'));
 	} else {
 		$login = trim($_POST['user_login']);
-		$user_data = get_userdatabylogin($login);
+		$user_data = get_user_data_by_login($login);
 	}
 
 	do_action('lostpassword_post');
@@ -252,7 +252,7 @@
 
 nocache_headers();
 
-header('Content-Type: '.get_bloginfo('html_type').'; charset='.get_bloginfo('charset'));
+header('Content-Type: '.get_blog_info('html_type').'; charset='.get_blog_info('charset'));
 
 if ( defined('RELOCATE') ) { // Move flag is set
 	if ( isset( $_SERVER['PATH_INFO'] ) && ($_SERVER['PATH_INFO'] != $_SERVER['PHP_SELF']) )
@@ -323,7 +323,7 @@
 
 </div>
 
-<p id="backtoblog"><a href="<?php bloginfo('url'); ?>/" title="<?php _e('Are you lost?') ?>"><?php printf(__('&larr; Back to %s'), get_bloginfo('title', 'display' )); ?></a></p>
+<p id="backtoblog"><a href="<?php bloginfo('url'); ?>/" title="<?php _e('Are you lost?') ?>"><?php printf(__('&larr; Back to %s'), get_blog_info('title', 'display' )); ?></a></p>
 
 <script type="text/javascript">
 try{document.getElementById('user_login').focus();}catch(e){}
@@ -391,7 +391,7 @@
 
 </div>
 
-<p id="backtoblog"><a href="<?php bloginfo('url'); ?>/" title="<?php _e('Are you lost?') ?>"><?php printf(__('&larr; Back to %s'), get_bloginfo('title', 'display' )); ?></a></p>
+<p id="backtoblog"><a href="<?php bloginfo('url'); ?>/" title="<?php _e('Are you lost?') ?>"><?php printf(__('&larr; Back to %s'), get_blog_info('title', 'display' )); ?></a></p>
 
 <script type="text/javascript">
 try{document.getElementById('user_login').focus();}catch(e){}
@@ -408,7 +408,7 @@
 	// If the user wants ssl but the session is not ssl, force a secure cookie.
 	if ( !empty($_POST['log']) && !force_ssl_admin() ) {
 		$user_name = sanitize_user($_POST['log']);
-		if ( $user = get_userdatabylogin($user_name) ) {
+		if ( $user = get_user_data_by_login($user_name) ) {
 			if ( get_user_option('use_ssl', $user->ID) ) {
 				$secure_cookie = true;
 				force_ssl_admin(true);
@@ -494,7 +494,7 @@
 
 </div>
 
-<p id="backtoblog"><a href="<?php bloginfo('url'); ?>/" title="<?php _e('Are you lost?') ?>"><?php printf(__('&larr; Back to %s'), get_bloginfo('title', 'display' )); ?></a></p>
+<p id="backtoblog"><a href="<?php bloginfo('url'); ?>/" title="<?php _e('Are you lost?') ?>"><?php printf(__('&larr; Back to %s'), get_blog_info('title', 'display' )); ?></a></p>
 
 <script type="text/javascript">
 <?php if ( $user_login ) { ?>
Index: wp-rdf.php
===================================================================
--- wp-rdf.php	(revision 10289)
+++ wp-rdf.php	(working copy)
@@ -7,6 +7,6 @@
  */
 
 require( './wp-load.php' );
-wp_redirect( get_bloginfo( 'rdf_url' ), 301 );
+wp_redirect( get_blog_info( 'rdf_url' ), 301 );
 
 ?>
\ No newline at end of file
Index: wp-app.php
===================================================================
--- wp-app.php	(revision 10289)
+++ wp-app.php	(working copy)
@@ -245,7 +245,7 @@
 	function AtomServer() {
 
 		$this->script_name = array_pop(explode('/',$_SERVER['SCRIPT_NAME']));
-		$this->app_base = get_bloginfo('url') . '/' . $this->script_name . '/';
+		$this->app_base = get_blog_info('url') . '/' . $this->script_name . '/';
 		if ( isset($_SERVER['HTTPS']) && strtolower($_SERVER['HTTPS']) == 'on' ) {
 			$this->app_base = preg_replace( '/^http:\/\//', 'https://', $this->app_base );
 		}
@@ -356,7 +356,7 @@
 			$accepted_media_types = $accepted_media_types . "<accept>" . $med . "</accept>";
 		}
 		$atom_prefix="atom";
-		$atom_blogname=get_bloginfo('name');
+		$atom_blogname=get_blog_info('name');
 		$service_doc = <<<EOD
 <service xmlns="$this->ATOMPUB_NS" xmlns:$atom_prefix="$this->ATOM_NS">
   <workspace>
@@ -389,7 +389,7 @@
 		if( !current_user_can( 'edit_posts' ) )
 			$this->auth_required( __( 'Sorry, you do not have the right to access this blog.' ) );
 
-		$home = attribute_escape(get_bloginfo_rss('home'));
+		$home = attribute_escape(get_blog_info_rss('home'));
 
 		$categories = "";
 		$cats = get_categories("hierarchical=0&hide_empty=0");
@@ -1092,7 +1092,7 @@
 		$self_page = $page > 1 ? $page : NULL;
 ?><feed xmlns="<?php echo $this->ATOM_NS ?>" xmlns:app="<?php echo $this->ATOMPUB_NS ?>" xml:lang="<?php echo get_option('rss_language'); ?>">
 <id><?php $this->the_entries_url() ?></id>
-<updated><?php echo mysql2date('Y-m-d\TH:i:s\Z', get_lastpostmodified('GMT')); ?></updated>
+<updated><?php echo mysql2date('Y-m-d\TH:i:s\Z', get_last_post_modified('GMT')); ?></updated>
 <title type="text"><?php bloginfo_rss('name') ?></title>
 <subtitle type="text"><?php bloginfo_rss("description") ?></subtitle>
 <link rel="first" type="<?php echo $this->ATOM_CONTENT_TYPE ?>" href="<?php $this->the_entries_url() ?>" />
@@ -1104,7 +1104,7 @@
 <?php endif; ?>
 <link rel="last" type="<?php echo $this->ATOM_CONTENT_TYPE ?>" href="<?php $this->the_entries_url($last_page) ?>" />
 <link rel="self" type="<?php echo $this->ATOM_CONTENT_TYPE ?>" href="<?php $this->the_entries_url($self_page) ?>" />
-<rights type="text">Copyright <?php echo mysql2date('Y', get_lastpostdate('blog')); ?></rights>
+<rights type="text">Copyright <?php echo mysql2date('Y', get_last_post_date('blog')); ?></rights>
 <?php the_generator( 'atom' ); ?>
 <?php if ( have_posts() ) {
 			while ( have_posts() ) {
@@ -1542,7 +1542,7 @@
 				$post = NULL;
 				break;
 			case $this->ENTRIES_PATH:
-				$wp_last_modified = mysql2date('D, d M Y H:i:s', get_lastpostmodified('GMT'), 0).' GMT';
+				$wp_last_modified = mysql2date('D, d M Y H:i:s', get_last_post_modified('GMT'), 0).' GMT';
 				break;
 			default:
 				return;
Index: wp-includes/feed-rss2.php
===================================================================
--- wp-includes/feed-rss2.php	(revision 10289)
+++ wp-includes/feed-rss2.php	(working copy)
@@ -25,7 +25,7 @@
 	<atom:link href="<?php self_link(); ?>" rel="self" type="application/rss+xml" />
 	<link><?php bloginfo_rss('url') ?></link>
 	<description><?php bloginfo_rss("description") ?></description>
-	<pubDate><?php echo mysql2date('D, d M Y H:i:s +0000', get_lastpostmodified('GMT'), false); ?></pubDate>
+	<pubDate><?php echo mysql2date('D, d M Y H:i:s +0000', get_last_post_modified('GMT'), false); ?></pubDate>
 	<?php the_generator( 'rss2' ); ?>
 	<language><?php echo get_option('rss_language'); ?></language>
 	<sy:updatePeriod><?php echo apply_filters( 'rss_update_period', 'hourly' ); ?></sy:updatePeriod>
Index: wp-includes/feed-atom.php
===================================================================
--- wp-includes/feed-atom.php	(revision 10289)
+++ wp-includes/feed-atom.php	(working copy)
@@ -20,7 +20,7 @@
 	<title type="text"><?php bloginfo_rss('name'); wp_title_rss(); ?></title>
 	<subtitle type="text"><?php bloginfo_rss("description") ?></subtitle>
 
-	<updated><?php echo mysql2date('Y-m-d\TH:i:s\Z', get_lastpostmodified('GMT')); ?></updated>
+	<updated><?php echo mysql2date('Y-m-d\TH:i:s\Z', get_last_post_modified('GMT')); ?></updated>
 	<?php the_generator( 'atom' ); ?>
 
 	<link rel="alternate" type="text/html" href="<?php bloginfo_rss('home') ?>" />
Index: wp-includes/category.php
===================================================================
--- wp-includes/category.php	(revision 10289)
+++ wp-includes/category.php	(working copy)
@@ -173,21 +173,6 @@
 
 
 /**
- * Retrieve the category name by the category ID.
- *
- * @since 0.71
- * @deprecated Use get_cat_name()
- * @see get_cat_name() get_catname() is deprecated in favor of get_cat_name().
- *
- * @param int $cat_ID Category ID
- * @return string category name
- */
-function get_catname( $cat_ID ) {
-	return get_cat_name( $cat_ID );
-}
-
-
-/**
  * Retrieve the name of a category from its ID.
  *
  * @since 1.0.0
Index: wp-includes/update.php
===================================================================
--- wp-includes/update.php	(revision 10289)
+++ wp-includes/update.php	(working copy)
@@ -51,7 +51,7 @@
 
 	$options = array(
 		'timeout' => 3,
-		'user-agent' => 'WordPress/' . $wp_version . '; ' . get_bloginfo( 'url' )
+		'user-agent' => 'WordPress/' . $wp_version . '; ' . get_blog_info( 'url' )
 	);
 
 	$response = wp_remote_get($url, $options);
@@ -152,7 +152,7 @@
 	$options = array(
 		'timeout' => 3,
 		'body' => array( 'plugins' => serialize( $to_send ) ),
-		'user-agent' => 'WordPress/' . $wp_version . '; ' . get_bloginfo( 'url' )
+		'user-agent' => 'WordPress/' . $wp_version . '; ' . get_blog_info( 'url' )
 	);
 
 	$raw_response = wp_remote_post('http://api.wordpress.org/plugins/update-check/1.0/', $options);
@@ -225,7 +225,7 @@
 	$options = array(
 		'timeout'		=> 3,
 		'body'			=> array( 'themes' => serialize( $themes ) ),
-		'user-agent'	=> 'WordPress/' . $wp_version . '; ' . get_bloginfo( 'url' )
+		'user-agent'	=> 'WordPress/' . $wp_version . '; ' . get_blog_info( 'url' )
 	);
 
 	$raw_response = wp_remote_post( 'http://api.wordpress.org/themes/update-check/1.0/', $options );
Index: wp-includes/post.php
===================================================================
--- wp-includes/post.php	(revision 10289)
+++ wp-includes/post.php	(working copy)
@@ -594,7 +594,7 @@
 	$meta_cache = wp_cache_get($post_id, 'post_meta');
 
 	if ( !$meta_cache ) {
-		update_postmeta_cache($post_id);
+		update_post_meta_cache($post_id);
 		$meta_cache = wp_cache_get($post_id, 'post_meta');
 	}
 
@@ -699,7 +699,7 @@
 	$post_id = (int) $post_id;
 
 	if ( ! wp_cache_get($post_id, 'post_meta') )
-		update_postmeta_cache($post_id);
+		update_post_meta_cache($post_id);
 
 	return wp_cache_get($post_id, 'post_meta');
 }
@@ -2183,7 +2183,7 @@
 			foreach ( $post_authors as $post_author ) {
 				//Do we have an author id or an author login?
 				if ( 0 == intval($post_author) ) {
-					$post_author = get_userdatabylogin($post_author);
+					$post_author = get_user_data_by_login($post_author);
 					if ( empty($post_author) )
 						continue;
 					if ( empty($post_author->ID) )
@@ -2273,9 +2273,9 @@
  * @return bool True on success, false on failure.
  */
 function is_local_attachment($url) {
-	if (strpos($url, get_bloginfo('url')) === false)
+	if (strpos($url, get_blog_info('url')) === false)
 		return false;
-	if (strpos($url, get_bloginfo('url') . '/?attachment_id=') !== false)
+	if (strpos($url, get_blog_info('url') . '/?attachment_id=') !== false)
 		return true;
 	if ( $id = url_to_postid($url) ) {
 		$post = & get_post($id);
@@ -2874,7 +2874,7 @@
  * server time. The 'blog' value is the date when the last post was posted. The
  * 'gmt' is when the last post was posted in GMT formatted date.
  *
- * @since 0.71
+ * @since 2.8
  *
  * @uses $wpdb
  * @uses $blog_id
@@ -2886,7 +2886,7 @@
  * @param string $timezone The location to get the time. Can be 'gmt', 'blog', or 'server'.
  * @return string The date of the last post.
  */
-function get_lastpostdate($timezone = 'server') {
+function get_last_post_date($timezone = 'server') {
 	global $cache_lastpostdate, $wpdb, $blog_id;
 	$add_seconds_server = date('Z');
 	if ( !isset($cache_lastpostdate[$blog_id][$timezone]) ) {
@@ -2915,7 +2915,7 @@
  * server time. The 'blog' value is just when the last post was modified. The
  * 'gmt' is when the last post was modified in GMT time.
  *
- * @since 1.2.0
+ * @since 2.8
  * @uses $wpdb
  * @uses $blog_id
  * @uses apply_filters() Calls 'get_lastpostmodified' filter
@@ -2925,7 +2925,7 @@
  * @param string $timezone The location to get the time. Can be 'gmt', 'blog', or 'server'.
  * @return string The date the post was last modified.
  */
-function get_lastpostmodified($timezone = 'server') {
+function get_last_post_modified($timezone = 'server') {
 	global $cache_lastpostmodified, $wpdb, $blog_id;
 	$add_seconds_server = date('Z');
 	if ( !isset($cache_lastpostmodified[$blog_id][$timezone]) ) {
@@ -2940,7 +2940,7 @@
 				$lastpostmodified = $wpdb->get_var("SELECT DATE_ADD(post_modified_gmt, INTERVAL '$add_seconds_server' SECOND) FROM $wpdb->posts WHERE post_status = 'publish' ORDER BY post_modified_gmt DESC LIMIT 1");
 				break;
 		}
-		$lastpostdate = get_lastpostdate($timezone);
+		$lastpostdate = get_last_post_date($timezone);
 		if ( $lastpostdate > $lastpostmodified ) {
 			$lastpostmodified = $lastpostdate;
 		}
@@ -3055,7 +3055,7 @@
  * @uses $wpdb
  * @uses update_post_cache()
  * @uses update_object_term_cache()
- * @uses update_postmeta_cache()
+ * @uses update_post_meta_cache()
  *
  * @param array $posts Array of Post objects
  */
@@ -3073,7 +3073,7 @@
 
 	update_object_term_cache($post_ids, 'post');
 
-	update_postmeta_cache($post_ids);
+	update_post_meta_cache($post_ids);
 }
 
 /**
@@ -3085,14 +3085,14 @@
  *
  * @package WordPress
  * @subpackage Cache
- * @since 2.1.0
+ * @since 2.8
  *
  * @uses $wpdb
  *
  * @param array $post_ids List of post IDs.
  * @return bool|array Returns false if there is nothing to update or an array of metadata.
  */
-function update_postmeta_cache($post_ids) {
+function update_post_meta_cache($post_ids) {
 	global $wpdb;
 
 	if ( empty( $post_ids ) )
Index: wp-includes/js/tinymce/wp-mce-help.php
===================================================================
--- wp-includes/js/tinymce/wp-mce-help.php	(revision 10289)
+++ wp-includes/js/tinymce/wp-mce-help.php	(working copy)
@@ -7,7 +7,7 @@
 
 /** @ignore */
 require_once('../../../wp-load.php');
-header('Content-Type: text/html; charset=' . get_bloginfo('charset'));
+header('Content-Type: text/html; charset=' . get_blog_info('charset'));
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml" <?php language_attributes(); ?>>
@@ -168,7 +168,7 @@
 </head>
 <body>
 
-<div id="wphead"><h1><?php echo get_bloginfo('blogtitle'); ?></h1></div>
+<div id="wphead"><h1><?php echo get_blog_info('blogtitle'); ?></h1></div>
 
 <ul id="tabs">
 	<li><a id="tab1" href="javascript:flipTab(1)" title="<?php _e('Basics of Rich Editing') ?>" accesskey="1" tabindex="1" class="current"><?php _e('Basics') ?></a></li>
@@ -240,7 +240,7 @@
 	<h2><?php _e('About TinyMCE'); ?></h2>
 
     <p><?php _e('Version:'); ?> <span id="version"></span> (<span id="date"></span>)</p>
-	<p><?php printf(__('TinyMCE is a platform independent web based Javascript HTML WYSIWYG editor control released as Open Source under %sLGPL</a>	by Moxiecode Systems AB. It has the ability to convert HTML TEXTAREA fields or other HTML elements to editor instances.'), '<a href="'.get_bloginfo('url').'/wp-includes/js/tinymce/license.txt" target="_blank" title="'.__('GNU Library General Public Licence').'">') ?></p>
+	<p><?php printf(__('TinyMCE is a platform independent web based Javascript HTML WYSIWYG editor control released as Open Source under %sLGPL</a>	by Moxiecode Systems AB. It has the ability to convert HTML TEXTAREA fields or other HTML elements to editor instances.'), '<a href="'.get_blog_info('url').'/wp-includes/js/tinymce/license.txt" target="_blank" title="'.__('GNU Library General Public Licence').'">') ?></p>
 	<p><?php _e('Copyright &copy; 2003-2007, <a href="http://www.moxiecode.com" target="_blank">Moxiecode Systems AB</a>, All rights reserved.') ?></p>
 	<p><?php _e('For more information about this software visit the <a href="http://tinymce.moxiecode.com" target="_blank">TinyMCE website</a>.') ?></p>
 
Index: wp-includes/theme.php
===================================================================
--- wp-includes/theme.php	(revision 10289)
+++ wp-includes/theme.php	(working copy)
@@ -1051,7 +1051,7 @@
  *
  * @return string
  */
-function get_header_textcolor() {
+function get_header_text_color() {
 	return get_theme_mod('header_textcolor', HEADER_TEXTCOLOR);
 }
 
@@ -1061,7 +1061,7 @@
  * @since 2.1.0
  */
 function header_textcolor() {
-	echo get_header_textcolor();
+	echo get_header_text_color();
 }
 
 /**
Index: wp-includes/comment.php
===================================================================
--- wp-includes/comment.php	(revision 10289)
+++ wp-includes/comment.php	(working copy)
@@ -263,7 +263,7 @@
 /**
  * The date the last comment was modified.
  *
- * @since 1.5.0
+ * @since 2.8
  * @uses $wpdb
  * @global array $cache_lastcommentmodified
  *
@@ -271,7 +271,7 @@
  *		or 'server' locations.
  * @return string Last comment modified date.
  */
-function get_lastcommentmodified($timezone = 'server') {
+function get_last_comment_modified($timezone = 'server') {
 	global $cache_lastcommentmodified, $wpdb;
 
 	if ( isset($cache_lastcommentmodified[$timezone]) )
@@ -416,7 +416,7 @@
 	do_action( 'check_comment_flood', $comment_author_IP, $comment_author_email, $comment_date_gmt );
 
 	if ( $user_id ) {
-		$userdata = get_userdata($user_id);
+		$userdata = get_user_data($user_id);
 		$user = new WP_User($user_id);
 		$post_author = $wpdb->get_var($wpdb->prepare("SELECT post_author FROM $wpdb->posts WHERE ID = %d LIMIT 1", $comment_post_ID));
 	}
@@ -1527,7 +1527,7 @@
 	// when set to true, this outputs debug messages by itself
 	$client->debug = false;
 	$home = trailingslashit( get_option('home') );
-	if ( !$client->query('weblogUpdates.extendedPing', get_option('blogname'), $home, get_bloginfo('rss2_url') ) ) // then try a normal ping
+	if ( !$client->query('weblogUpdates.extendedPing', get_option('blogname'), $home, get_blog_info('rss2_url') ) ) // then try a normal ping
 		$client->query('weblogUpdates.ping', get_option('blogname'), $home);
 }
 
Index: wp-includes/feed-rss.php
===================================================================
--- wp-includes/feed-rss.php	(revision 10289)
+++ wp-includes/feed-rss.php	(working copy)
@@ -16,7 +16,7 @@
 	<title><?php bloginfo_rss('name'); wp_title_rss(); ?></title>
 	<link><?php bloginfo_rss('url') ?></link>
 	<description><?php bloginfo_rss('description') ?></description>
-	<lastBuildDate><?php echo mysql2date('D, d M Y H:i:s +0000', get_lastpostmodified('GMT'), false); ?></lastBuildDate>
+	<lastBuildDate><?php echo mysql2date('D, d M Y H:i:s +0000', get_last_post_modified('GMT'), false); ?></lastBuildDate>
 	<docs>http://backend.userland.com/rss092</docs>
 	<language><?php echo get_option('rss_language'); ?></language>
 	<?php do_action('rss_head'); ?>
Index: wp-includes/registration.php
===================================================================
--- wp-includes/registration.php	(revision 10289)
+++ wp-includes/registration.php	(working copy)
@@ -14,7 +14,7 @@
  * @return null|int The user's ID on success, and null on failure.
  */
 function username_exists( $username ) {
-	if ( $user = get_userdatabylogin( $username ) ) {
+	if ( $user = get_user_data_by_login( $username ) ) {
 		return $user->ID;
 	} else {
 		return null;
@@ -109,7 +109,7 @@
 	if ( !empty($ID) ) {
 		$ID = (int) $ID;
 		$update = true;
-		$old_user_data = get_userdata($ID);
+		$old_user_data = get_user_data($ID);
 	} else {
 		$update = false;
 		// Hash the password
@@ -187,17 +187,17 @@
 		$user_id = (int) $wpdb->insert_id;
 	}
 
-	update_usermeta( $user_id, 'first_name', $first_name);
-	update_usermeta( $user_id, 'last_name', $last_name);
-	update_usermeta( $user_id, 'nickname', $nickname );
-	update_usermeta( $user_id, 'description', $description );
-	update_usermeta( $user_id, 'jabber', $jabber );
-	update_usermeta( $user_id, 'aim', $aim );
-	update_usermeta( $user_id, 'yim', $yim );
-	update_usermeta( $user_id, 'rich_editing', $rich_editing);
-	update_usermeta( $user_id, 'comment_shortcuts', $comment_shortcuts);
-	update_usermeta( $user_id, 'admin_color', $admin_color);
-	update_usermeta( $user_id, 'use_ssl', $use_ssl);
+	update_user_meta( $user_id, 'first_name', $first_name);
+	update_user_meta( $user_id, 'last_name', $last_name);
+	update_user_meta( $user_id, 'nickname', $nickname );
+	update_user_meta( $user_id, 'description', $description );
+	update_user_meta( $user_id, 'jabber', $jabber );
+	update_user_meta( $user_id, 'aim', $aim );
+	update_user_meta( $user_id, 'yim', $yim );
+	update_user_meta( $user_id, 'rich_editing', $rich_editing);
+	update_user_meta( $user_id, 'comment_shortcuts', $comment_shortcuts);
+	update_user_meta( $user_id, 'admin_color', $admin_color);
+	update_user_meta( $user_id, 'use_ssl', $use_ssl);
 
 	if ( $update && isset($role) ) {
 		$user = new WP_User($user_id);
@@ -243,7 +243,7 @@
 	$ID = (int) $userdata['ID'];
 
 	// First, get all of the original fields
-	$user = get_userdata($ID);
+	$user = get_user_data($ID);
 
 	// Escape data pulled from DB.
 	$user = add_magic_quotes(get_object_vars($user));
Index: wp-includes/comment-template.php
===================================================================
--- wp-includes/comment-template.php	(revision 10289)
+++ wp-includes/comment-template.php	(working copy)
@@ -23,7 +23,7 @@
 	global $comment;
 	if ( empty($comment->comment_author) ) {
 		if (!empty($comment->user_id)){
-			$user=get_userdata($comment->user_id);
+			$user=get_user_data($comment->user_id);
 			$author=$user->user_login;
 		} else {
 			$author = __('Anonymous');
@@ -290,7 +290,7 @@
 	$classes[] = ( empty( $comment->comment_type ) ) ? 'comment' : $comment->comment_type;
 
 	// If the comment author has an id (registered), then print the log in name
-	if ( $comment->user_id > 0 && $user = get_userdata($comment->user_id) ) {
+	if ( $comment->user_id > 0 && $user = get_user_data($comment->user_id) ) {
 		// For all registered users, 'byuser'
 		$classes[] = 'byuser comment-author-' . $user->user_nicename;
 		// For comment authors who are the author of the post
Index: wp-includes/feed-rdf.php
===================================================================
--- wp-includes/feed-rdf.php	(revision 10289)
+++ wp-includes/feed-rdf.php	(working copy)
@@ -23,7 +23,7 @@
 	<title><?php bloginfo_rss('name'); wp_title_rss(); ?></title>
 	<link><?php bloginfo_rss('url') ?></link>
 	<description><?php bloginfo_rss('description') ?></description>
-	<dc:date><?php echo mysql2date('Y-m-d\TH:i:s\Z', get_lastpostmodified('GMT'), false); ?></dc:date>
+	<dc:date><?php echo mysql2date('Y-m-d\TH:i:s\Z', get_last_post_modified('GMT'), false); ?></dc:date>
 	<?php the_generator( 'rdf' ); ?>
 	<sy:updatePeriod>hourly</sy:updatePeriod>
 	<sy:updateFrequency>1</sy:updateFrequency>
Index: wp-includes/user.php
===================================================================
--- wp-includes/user.php	(revision 10289)
+++ wp-includes/user.php	(working copy)
@@ -114,13 +114,13 @@
 /**
  * Number of posts user has written.
  *
- * @since 0.71
+ * @since 2.8
  * @uses $wpdb WordPress database object for queries.
  *
  * @param int $userid User ID.
  * @return int Amount of posts user has written.
  */
-function get_usernumposts($userid) {
+function get_user_num_posts($userid) {
 	global $wpdb;
 	$userid = (int) $userid;
 	$count = $wpdb->get_var( $wpdb->prepare("SELECT COUNT(*) FROM $wpdb->posts WHERE post_author = %d AND post_type = 'post' AND ", $userid) . get_private_posts_cap_sql('post'));
@@ -178,7 +178,7 @@
 	if ( empty($user) )
 		$user = wp_get_current_user();
 	else
-		$user = get_userdata($user);
+		$user = get_user_data($user);
 
 	if ( isset( $user->{$wpdb->prefix . $option} ) ) // Blog specific
 		$result = $user->{$wpdb->prefix . $option};
@@ -212,7 +212,7 @@
 	global $wpdb;
 	if ( !$global )
 		$option_name = $wpdb->prefix . $option_name;
-	return update_usermeta( $user_id, $option_name, $newvalue );
+	return update_user_meta( $user_id, $option_name, $newvalue );
 }
 
 /**
@@ -243,7 +243,7 @@
 /**
  * Remove user meta data.
  *
- * @since 2.0.0
+ * @since 2.8
  * @uses $wpdb WordPress database object for queries.
  *
  * @param int $user_id User ID.
@@ -251,7 +251,7 @@
  * @param mixed $meta_value Metadata value.
  * @return bool True deletion completed and false if user_id is not a number.
  */
-function delete_usermeta( $user_id, $meta_key, $meta_value = '' ) {
+function delete_user_meta( $user_id, $meta_key, $meta_value = '' ) {
 	global $wpdb;
 	if ( !is_numeric( $user_id ) )
 		return false;
@@ -279,14 +279,14 @@
  * one item to be returned, which be that single item type. If there is more
  * than one metadata value, then it will be list of metadata values.
  *
- * @since 2.0.0
+ * @since 2.8
  * @uses $wpdb WordPress database object for queries.
  *
  * @param int $user_id User ID
  * @param string $meta_key Optional. Metadata key.
  * @return mixed
  */
-function get_usermeta( $user_id, $meta_key = '') {
+function get_user_meta( $user_id, $meta_key = '') {
 	global $wpdb;
 	$user_id = (int) $user_id;
 
@@ -329,7 +329,7 @@
  *
  * Will remove the metadata, if the meta value is empty.
  *
- * @since 2.0.0
+ * @since 2.8
  * @uses $wpdb WordPress database object for queries
  *
  * @param int $user_id User ID
@@ -337,7 +337,7 @@
  * @param mixed $meta_value Metadata value.
  * @return bool True on successful update, false on failure.
  */
-function update_usermeta( $user_id, $meta_key, $meta_value ) {
+function update_user_meta( $user_id, $meta_key, $meta_value ) {
 	global $wpdb;
 	if ( !is_numeric( $user_id ) )
 		return false;
@@ -349,7 +349,7 @@
 	$meta_value = maybe_serialize($meta_value);
 
 	if (empty($meta_value)) {
-		return delete_usermeta($user_id, $meta_key);
+		return delete_user_meta($user_id, $meta_key);
 	}
 
 	$cur = $wpdb->get_row( $wpdb->prepare("SELECT * FROM $wpdb->usermeta WHERE user_id = %d AND meta_key = %s", $user_id, $meta_key) );
Index: wp-includes/feed-atom-comments.php
===================================================================
--- wp-includes/feed-atom-comments.php	(revision 10289)
+++ wp-includes/feed-atom-comments.php	(working copy)
@@ -18,13 +18,13 @@
 		if ( is_singular() )
 			printf(ent2ncr(__('Comments on: %s')), get_the_title_rss());
 		elseif ( is_search() )
-			printf(ent2ncr(__('Comments for %1$s searching on %2$s')), get_bloginfo_rss( 'name' ), attribute_escape(get_search_query()));
+			printf(ent2ncr(__('Comments for %1$s searching on %2$s')), get_blog_info_rss( 'name' ), attribute_escape(get_search_query()));
 		else
-			printf(ent2ncr(__('Comments for %s')), get_bloginfo_rss( 'name' ) . get_wp_title_rss());
+			printf(ent2ncr(__('Comments for %s')), get_blog_info_rss( 'name' ) . get_wp_title_rss());
 	?></title>
 	<subtitle type="text"><?php bloginfo_rss('description'); ?></subtitle>
 
-	<updated><?php echo mysql2date('Y-m-d\TH:i:s\Z', get_lastcommentmodified('GMT')); ?></updated>
+	<updated><?php echo mysql2date('Y-m-d\TH:i:s\Z', get_last_comment_modified('GMT')); ?></updated>
 	<?php the_generator( 'atom' ); ?>
 
 <?php if ( is_singular() ) { ?>
Index: wp-includes/query.php
===================================================================
--- wp-includes/query.php	(revision 10289)
+++ wp-includes/query.php	(working copy)
@@ -2555,7 +2555,7 @@
 			$this->queried_object_id = (int) $this->post->ID;
 		} else if ($this->is_author) {
 			$author_id = (int) $this->get('author');
-			$author = get_userdata($author_id);
+			$author = get_user_data($author_id);
 			$this->queried_object = $author;
 			$this->queried_object_id = $author_id;
 		}
@@ -2654,7 +2654,7 @@
 
 	$id = (int) $post->ID;
 
-	$authordata = get_userdata($post->post_author);
+	$authordata = get_user_data($post->post_author);
 
 	$day = mysql2date('d.m.y', $post->post_date);
 	$currentmonth = mysql2date('m', $post->post_date);
Index: wp-includes/link-template.php
===================================================================
--- wp-includes/link-template.php	(revision 10289)
+++ wp-includes/link-template.php	(working copy)
@@ -128,7 +128,7 @@
 
 		$author = '';
 		if ( strpos($permalink, '%author%') !== false ) {
-			$authordata = get_userdata($post->post_author);
+			$authordata = get_user_data($post->post_author);
 			$author = $authordata->user_nicename;
 		}
 
@@ -264,7 +264,7 @@
 	}
 
 	if (! $link ) {
-		$link = get_bloginfo('url') . "/?attachment_id=$id";
+		$link = get_blog_info('url') . "/?attachment_id=$id";
 	}
 
 	return apply_filters('attachment_link', $link, $id);
@@ -995,7 +995,7 @@
 	$request = preg_replace('|^/+|', '', $request);
 
 	if ( !$wp_rewrite->using_permalinks() || is_admin() ) {
-		$base = trailingslashit( get_bloginfo( 'home' ) );
+		$base = trailingslashit( get_blog_info( 'home' ) );
 
 		if ( $pagenum > 1 ) {
 			$result = add_query_arg( 'paged', $pagenum, $base . $request );
@@ -1017,7 +1017,7 @@
 		$request = preg_replace( '|^index\.php|', '', $request);
 		$request = ltrim($request, '/');
 
-		$base = trailingslashit( get_bloginfo( 'url' ) );
+		$base = trailingslashit( get_blog_info( 'url' ) );
 
 		if ( $wp_rewrite->using_index_permalinks() && ( $pagenum > 1 || '' != $request ) )
 			$base .= 'index.php/';
@@ -1211,12 +1211,12 @@
 /**
  * Retrieve page numbers links.
  *
- * @since 2.7.0
+ * @since 2.8
  *
  * @param int $pagenum Optional. Page number.
  * @return string
  */
-function get_comments_pagenum_link( $pagenum = 1, $max_page = 0 ) {
+function get_comments_page_num_link( $pagenum = 1, $max_page = 0 ) {
 	global $post, $wp_rewrite;
 
 	$pagenum = (int) $pagenum;
@@ -1275,7 +1275,7 @@
 	if ( empty($label) )
 		$label = __('Newer Comments &raquo;');
 
-	return '<a href="' . clean_url( get_comments_pagenum_link( $nextpage, $max_page ) ) . '" ' . apply_filters( 'next_comments_link_attributes', '' ) . '>'. preg_replace('/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $label) .'</a>';
+	return '<a href="' . clean_url( get_comments_page_num_link( $nextpage, $max_page ) ) . '" ' . apply_filters( 'next_comments_link_attributes', '' ) . '>'. preg_replace('/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $label) .'</a>';
 }
 
 /**
@@ -1312,7 +1312,7 @@
 	if ( empty($label) )
 		$label = __('&laquo; Older Comments');
 
-	return '<a href="' . clean_url( get_comments_pagenum_link( $prevpage ) ) . '" ' . apply_filters( 'previous_comments_link_attributes', '' ) . '>' . preg_replace('/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $label) .'</a>';
+	return '<a href="' . clean_url( get_comments_page_num_link( $prevpage ) ) . '" ' . apply_filters( 'previous_comments_link_attributes', '' ) . '>' . preg_replace('/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $label) .'</a>';
 }
 
 /**
Index: wp-includes/author-template.php
===================================================================
--- wp-includes/author-template.php	(revision 10289)
+++ wp-includes/author-template.php	(working copy)
@@ -354,12 +354,12 @@
  *
  * @since 1.5
  * @uses $post The current post in the Loop's DB object.
- * @uses get_usernumposts()
+ * @uses get_user_num_posts()
  * @return int The number of posts by the author.
  */
 function get_the_author_posts() {
 	global $post;
-	return get_usernumposts($post->post_author);
+	return get_user_num_posts($post->post_author);
 }
 
 /**
@@ -414,7 +414,7 @@
 		$link = $file . '?author=' . $auth_ID;
 	} else {
 		if ( '' == $author_nicename ) {
-			$user = get_userdata($author_id);
+			$user = get_user_data($author_id);
 			if ( !empty($user->user_nicename) )
 				$author_nicename = $user->user_nicename;
 		}
@@ -435,7 +435,7 @@
  * @return string The author's display name.
  */
 function get_author_name( $auth_id ) {
-	$authordata = get_userdata( $auth_id );
+	$authordata = get_user_data( $auth_id );
 	return $authordata->display_name;
 }
 
@@ -480,7 +480,7 @@
 	}
 
 	foreach ( (array) $authors as $author ) {
-		$author = get_userdata( $author->ID );
+		$author = get_user_data( $author->ID );
 		$posts = (isset($author_count[$author->ID])) ? $author_count[$author->ID] : 0;
 		$name = $author->display_name;
 
Index: wp-includes/feed-rss2-comments.php
===================================================================
--- wp-includes/feed-rss2-comments.php	(revision 10289)
+++ wp-includes/feed-rss2-comments.php	(working copy)
@@ -20,9 +20,9 @@
 		if ( is_singular() )
 			printf(ent2ncr(__('Comments on: %s')), get_the_title_rss());
 		elseif ( is_search() )
-			printf(ent2ncr(__('Comments for %s searching on %s')), get_bloginfo_rss( 'name' ), attribute_escape($wp_query->query_vars['s']));
+			printf(ent2ncr(__('Comments for %s searching on %s')), get_blog_info_rss( 'name' ), attribute_escape($wp_query->query_vars['s']));
 		else
-			printf(ent2ncr(__('Comments for %s')), get_bloginfo_rss( 'name' ) . get_wp_title_rss());
+			printf(ent2ncr(__('Comments for %s')), get_blog_info_rss( 'name' ) . get_wp_title_rss());
 	?></title>
 	<atom:link href="<?php self_link(); ?>" rel="self" type="application/rss+xml" />
 	<link><?php (is_single()) ? the_permalink_rss() : bloginfo_rss("url") ?></link>
Index: wp-includes/canonical.php
===================================================================
--- wp-includes/canonical.php	(revision 10289)
+++ wp-includes/canonical.php	(working copy)
@@ -123,7 +123,7 @@
 			if ( $redirect_url = get_category_link(get_query_var('cat')) )
 				$redirect['query'] = remove_query_arg('cat', $redirect['query']);
 		} elseif ( is_author() && !empty($_GET['author']) ) {
-			$author = get_userdata(get_query_var('author'));
+			$author = get_user_data(get_query_var('author'));
 			if ( false !== $author && $redirect_url = get_author_posts_url($author->ID, $author->user_nicename) )
 				$redirect['query'] = remove_query_arg('author', $redirect['author']);
 		}
Index: wp-includes/capabilities.php
===================================================================
--- wp-includes/capabilities.php	(revision 10289)
+++ wp-includes/capabilities.php	(working copy)
@@ -473,9 +473,9 @@
 		}
 
 		if ( ! empty( $id ) )
-			$this->data = get_userdata( $id );
+			$this->data = get_user_data( $id );
 		else
-			$this->data = get_userdatabylogin( $name );
+			$this->data = get_user_data_by_login( $name );
 
 		if ( empty( $this->data->ID ) )
 			return;
@@ -551,7 +551,7 @@
 	 */
 	function add_role( $role ) {
 		$this->caps[$role] = true;
-		update_usermeta( $this->ID, $this->cap_key, $this->caps );
+		update_user_meta( $this->ID, $this->cap_key, $this->caps );
 		$this->get_role_caps();
 		$this->update_user_level_from_caps();
 	}
@@ -568,7 +568,7 @@
 		if ( empty( $this->roles[$role] ) || ( count( $this->roles ) <= 1 ) )
 			return;
 		unset( $this->caps[$role] );
-		update_usermeta( $this->ID, $this->cap_key, $this->caps );
+		update_user_meta( $this->ID, $this->cap_key, $this->caps );
 		$this->get_role_caps();
 	}
 
@@ -593,7 +593,7 @@
 		} else {
 			$this->roles = false;
 		}
-		update_usermeta( $this->ID, $this->cap_key, $this->caps );
+		update_user_meta( $this->ID, $this->cap_key, $this->caps );
 		$this->get_role_caps();
 		$this->update_user_level_from_caps();
 	}
@@ -639,7 +639,7 @@
 	function update_user_level_from_caps() {
 		global $wpdb;
 		$this->user_level = array_reduce( array_keys( $this->allcaps ), array( &$this, 'level_reduction' ), 0 );
-		update_usermeta( $this->ID, $wpdb->prefix.'user_level', $this->user_level );
+		update_user_meta( $this->ID, $wpdb->prefix.'user_level', $this->user_level );
 	}
 
 	/**
@@ -653,7 +653,7 @@
 	 */
 	function add_cap( $cap, $grant = true ) {
 		$this->caps[$cap] = $grant;
-		update_usermeta( $this->ID, $this->cap_key, $this->caps );
+		update_user_meta( $this->ID, $this->cap_key, $this->caps );
 	}
 
 	/**
@@ -667,7 +667,7 @@
 	function remove_cap( $cap ) {
 		if ( empty( $this->caps[$cap] ) ) return;
 		unset( $this->caps[$cap] );
-		update_usermeta( $this->ID, $this->cap_key, $this->caps );
+		update_user_meta( $this->ID, $this->cap_key, $this->caps );
 	}
 
 	/**
@@ -679,8 +679,8 @@
 	function remove_all_caps() {
 		global $wpdb;
 		$this->caps = array();
-		update_usermeta( $this->ID, $this->cap_key, '' );
-		update_usermeta( $this->ID, $wpdb->prefix.'user_level', '' );
+		update_user_meta( $this->ID, $this->cap_key, '' );
+		update_user_meta( $this->ID, $wpdb->prefix.'user_level', '' );
 		$this->get_role_caps();
 	}
 
@@ -761,14 +761,14 @@
 		}
 		break;
 	case 'delete_post':
-		$author_data = get_userdata( $user_id );
+		$author_data = get_user_data( $user_id );
 		//echo "post ID: {$args[0]}<br />";
 		$post = get_post( $args[0] );
 		if ( 'page' == $post->post_type ) {
 			$args = array_merge( array( 'delete_page', $user_id ), $args );
 			return call_user_func_array( 'map_meta_cap', $args );
 		}
-		$post_author_data = get_userdata( $post->post_author );
+		$post_author_data = get_user_data( $post->post_author );
 		//echo "current user id : $user_id, post author id: " . $post_author_data->ID . "<br />";
 		// If the user is the author...
 		if ( $user_id == $post_author_data->ID ) {
@@ -789,10 +789,10 @@
 		}
 		break;
 	case 'delete_page':
-		$author_data = get_userdata( $user_id );
+		$author_data = get_user_data( $user_id );
 		//echo "post ID: {$args[0]}<br />";
 		$page = get_page( $args[0] );
-		$page_author_data = get_userdata( $page->post_author );
+		$page_author_data = get_user_data( $page->post_author );
 		//echo "current user id : $user_id, page author id: " . $page_author_data->ID . "<br />";
 		// If the user is the author...
 		if ( $user_id == $page_author_data->ID ) {
@@ -815,14 +815,14 @@
 		// edit_post breaks down to edit_posts, edit_published_posts, or
 		// edit_others_posts
 	case 'edit_post':
-		$author_data = get_userdata( $user_id );
+		$author_data = get_user_data( $user_id );
 		//echo "post ID: {$args[0]}<br />";
 		$post = get_post( $args[0] );
 		if ( 'page' == $post->post_type ) {
 			$args = array_merge( array( 'edit_page', $user_id ), $args );
 			return call_user_func_array( 'map_meta_cap', $args );
 		}
-		$post_author_data = get_userdata( $post->post_author );
+		$post_author_data = get_user_data( $post->post_author );
 		//echo "current user id : $user_id, post author id: " . $post_author_data->ID . "<br />";
 		// If the user is the author...
 		if ( $user_id == $post_author_data->ID ) {
@@ -843,10 +843,10 @@
 		}
 		break;
 	case 'edit_page':
-		$author_data = get_userdata( $user_id );
+		$author_data = get_user_data( $user_id );
 		//echo "post ID: {$args[0]}<br />";
 		$page = get_page( $args[0] );
-		$page_author_data = get_userdata( $page->post_author );
+		$page_author_data = get_user_data( $page->post_author );
 		//echo "current user id : $user_id, page author id: " . $page_author_data->ID . "<br />";
 		// If the user is the author...
 		if ( $user_id == $page_author_data->ID ) {
@@ -878,8 +878,8 @@
 			break;
 		}
 
-		$author_data = get_userdata( $user_id );
-		$post_author_data = get_userdata( $post->post_author );
+		$author_data = get_user_data( $user_id );
+		$post_author_data = get_user_data( $post->post_author );
 		if ( $user_id == $post_author_data->ID )
 			$caps[] = 'read';
 		else
@@ -893,8 +893,8 @@
 			break;
 		}
 
-		$author_data = get_userdata( $user_id );
-		$page_author_data = get_userdata( $page->post_author );
+		$author_data = get_user_data( $user_id );
+		$page_author_data = get_user_data( $page->post_author );
 		if ( $user_id == $page_author_data->ID )
 			$caps[] = 'read';
 		else
Index: wp-includes/classes.php
===================================================================
--- wp-includes/classes.php	(revision 10289)
+++ wp-includes/classes.php	(working copy)
@@ -302,7 +302,7 @@
 	 * @since 2.0.0
 	 */
 	function send_headers() {
-		@header('X-Pingback: '. get_bloginfo('pingback_url'));
+		@header('X-Pingback: '. get_blog_info('pingback_url'));
 		if ( is_user_logged_in() )
 			nocache_headers();
 		if ( !empty($this->query_vars['error']) && '404' == $this->query_vars['error'] ) {
@@ -325,9 +325,9 @@
 					)
 				)
 			)
-				$wp_last_modified = mysql2date('D, d M Y H:i:s', get_lastcommentmodified('GMT'), 0).' GMT';
+				$wp_last_modified = mysql2date('D, d M Y H:i:s', get_last_comment_modified('GMT'), 0).' GMT';
 			else
-				$wp_last_modified = mysql2date('D, d M Y H:i:s', get_lastpostmodified('GMT'), 0).' GMT';
+				$wp_last_modified = mysql2date('D, d M Y H:i:s', get_last_post_modified('GMT'), 0).' GMT';
 			$wp_etag = '"' . md5($wp_last_modified) . '"';
 			@header("Last-Modified: $wp_last_modified");
 			@header("ETag: $wp_etag");

Index: wp-includes/functions.php
===================================================================
--- wp-includes/functions.php	(revision 10289)
+++ wp-includes/functions.php	(working copy)
@@ -207,13 +207,13 @@
 /**
  * Get the week start and end from the datetime or date string from mysql.
  *
- * @since 0.71
+ * @since 2.8
  *
  * @param string $mysqlstring Date or datetime field type from mysql.
  * @param int $start_of_week Optional. Start of the week as an integer.
  * @return array Keys are 'start' and 'end'.
  */
-function get_weekstartend( $mysqlstring, $start_of_week = '' ) {
+function get_week_start_end( $mysqlstring, $start_of_week = '' ) {
 	$my = substr( $mysqlstring, 0, 4 ); // Mysql string Year
 	$mm = substr( $mysqlstring, 8, 2 ); // Mysql string Month
 	$md = substr( $mysqlstring, 5, 2 ); // Mysql string day
@@ -428,7 +428,7 @@
  *
  * it is called.
  *
- * @since 1.0.0
+ * @since 2.8
  * @package WordPress
  * @subpackage Option
  * @uses apply_filters() Calls 'pre_option_$optionname' hook with option value as parameter.
@@ -436,7 +436,7 @@
  *
  * @return array List of all options.
  */
-function get_alloptions() {
+function get_all_options() {
 	global $wpdb;
 	$show = $wpdb->hide_errors();
 	if ( !$options = $wpdb->get_results( "SELECT option_name, option_value FROM $wpdb->options WHERE autoload = 'yes'" ) )
@@ -457,7 +457,7 @@
 /**
  * Loads and caches all autoloaded options, if available or all options.
  *
  * This is different from get_alloptions(), in that this function will cache the
  * options and will return the cached options when called again.
  *
  * @since 2.2.0
@@ -788,7 +788,7 @@
 	if ( ! $user = wp_get_current_user() )
 		return;
 
-	delete_usermeta( $user->ID, 'user-settings' );
+	delete_user_meta( $user->ID, 'user-settings' );
 	setcookie('wp-settings-'.$user->ID, ' ', time() - 31536000, SITECOOKIEPATH);
 }
 
@@ -1417,7 +1417,7 @@
  */
 function cache_javascript_headers() {
 	$expiresOffset = 864000; // 10 days
-	header( "Content-Type: text/javascript; charset=" . get_bloginfo( 'charset' ) );
+	header( "Content-Type: text/javascript; charset=" . get_blog_info( 'charset' ) );
 	header( "Vary: Accept-Encoding" ); // Handle proxies
 	header( "Expires: " . gmdate( "D, d M Y H:i:s", time() + $expiresOffset ) . " GMT" );
 }
@@ -2128,8 +2128,8 @@
 		$trans['update']['attachment'] = array( __( 'Your attempt to edit this attachment: &quot;%s&quot; has failed.' ), 'get_the_title' );
 
 		$trans['add']['category']      = array( __( 'Your attempt to add this category has failed.' ), false );
-		$trans['delete']['category']   = array( __( 'Your attempt to delete this category: &quot;%s&quot; has failed.' ), 'get_catname' );
-		$trans['update']['category']   = array( __( 'Your attempt to edit this category: &quot;%s&quot; has failed.' ), 'get_catname' );
+		$trans['delete']['category']   = array( __( 'Your attempt to delete this category: &quot;%s&quot; has failed.' ), 'get_cat_name' );
+		$trans['update']['category']   = array( __( 'Your attempt to edit this category: &quot;%s&quot; has failed.' ), 'get_cat_name' );
 
 		$trans['delete']['comment']    = array( __( 'Your attempt to delete this comment: &quot;%s&quot; has failed.' ), 'use_id' );
 		$trans['unapprove']['comment'] = array( __( 'Your attempt to unapprove this comment: &quot;%s&quot; has failed.' ), 'use_id' );
@@ -2168,7 +2168,7 @@
 		$trans['edit']['theme']        = array( __( 'Your attempt to edit this theme file: &quot;%s&quot; has failed.' ), 'use_id' );
 		$trans['switch']['theme']      = array( __( 'Your attempt to switch to this theme: &quot;%s&quot; has failed.' ), 'use_id' );
 
-		$trans['log']['out']           = array( sprintf( __( 'You are attempting to log out of %s' ), get_bloginfo( 'sitename' ) ), false );
+		$trans['log']['out']           = array( sprintf( __( 'You are attempting to log out of %s' ), get_blog_info( 'sitename' ) ), false );
 
 		if ( isset( $trans[$verb][$noun] ) ) {
 			if ( !empty( $trans[$verb][$noun][1] ) ) {
@@ -2254,8 +2254,8 @@
 
 	if ( defined( 'WP_SITEURL' ) && '' != WP_SITEURL )
 		$admin_dir = WP_SITEURL . '/wp-admin/';
-	elseif ( function_exists( 'get_bloginfo' ) && '' != get_bloginfo( 'wpurl' ) )
-		$admin_dir = get_bloginfo( 'wpurl' ) . '/wp-admin/';
+	elseif ( function_exists( 'get_blog_info' ) && '' != get_blog_info( 'wpurl' ) )
+		$admin_dir = get_blog_info( 'wpurl' ) . '/wp-admin/';
 	elseif ( strpos( $_SERVER['PHP_SELF'], 'wp-admin' ) !== false )
 		$admin_dir = '';
 	else
@@ -457,7 +457,7 @@
  * Loads and caches all autoloaded options, if available or all options.
  *
- * This is different from get_alloptions(), in that this function will cache the
+ * This is different from get_all_options(), in that this function will cache the
  * options and will return the cached options when called again.
  *
Index: wp-includes/general-template.php
===================================================================
--- wp-includes/general-template.php	(revision 10289)
+++ wp-includes/general-template.php	(working copy)
@@ -214,13 +214,13 @@
 /**
  * Display information about the blog.
  *
  * @see get_bloginfo() For possible values for the parameter.
  * @since 0.71
  *
  * @param string $show What to display.
  */
 function bloginfo($show='') {
-	echo get_bloginfo($show, 'display');
+	echo get_blog_info($show, 'display');
 }
 
 /**
@@ -246,13 +246,13 @@
  * There are many other options and you should check the function contents:
  * {@source 32 37}
  *
- * @since 0.71
+ * @since 2.8
  *
  * @param string $show Blog info to retrieve.
  * @param string $filter How to filter what is retrieved.
  * @return string Mostly string values, might be empty.
  */
-function get_bloginfo($show = '', $filter = 'raw') {
+function get_blog_info($show = '', $filter = 'raw') {
 
 	switch($show) {
 		case 'url' :
@@ -407,7 +407,7 @@
 
 	// If there's an author
 	if ( !empty($author) ) {
-		$title = get_userdata($author);
+		$title = get_user_data($author);
 		$title = $title->display_name;
 	}
 	if ( !empty($author_name) ) {
@@ -832,7 +832,7 @@
 					if ( $arcresult->week != $arc_w_last ) {
 						$arc_year = $arcresult->yr;
 						$arc_w_last = $arcresult->week;
-						$arc_week = get_weekstartend($arcresult->yyyymmdd, get_option('start_of_week'));
+						$arc_week = get_week_start_end($arcresult->yyyymmdd, get_option('start_of_week'));
 						$arc_week_start = date_i18n($archive_week_start_date_format, $arc_week['start']);
 						$arc_week_end = date_i18n($archive_week_end_date_format, $arc_week['end']);
 						$url  = sprintf('%1$s/%2$s%3$sm%4$s%5$s%6$sw%7$s%8$d', get_option('home'), '', '?', '=', $arc_year, '&amp;', '=', $arcresult->week);
@@ -1375,7 +1375,7 @@
  * @since 2.0.0
  */
 function rsd_link() {
-	echo '<link rel="EditURI" type="application/rsd+xml" title="RSD" href="' . get_bloginfo('wpurl') . "/xmlrpc.php?rsd\" />\n";
+	echo '<link rel="EditURI" type="application/rsd+xml" title="RSD" href="' . get_blog_info('wpurl') . "/xmlrpc.php?rsd\" />\n";
 }
 
 /**
@@ -1386,7 +1386,7 @@
  */
 function wlwmanifest_link() {
 	echo '<link rel="wlwmanifest" type="application/wlwmanifest+xml" href="'
-		. get_bloginfo('wpurl') . '/wp-includes/wlwmanifest.xml" /> ' . "\n";
+		. get_blog_info('wpurl') . '/wp-includes/wlwmanifest.xml" /> ' . "\n";
 }
 
 /**
@@ -1593,10 +1593,10 @@
 	$attributes = array();
 	$output = '';
 
-	if ( $dir = get_bloginfo('text_direction') )
+	if ( $dir = get_blog_info('text_direction') )
 		$attributes[] = "dir=\"$dir\"";
 
-	if ( $lang = get_bloginfo('language') ) {
+	if ( $lang = get_blog_info('language') ) {
 		if ( get_option('html_type') == 'text/html' || $doctype == 'html' )
 			$attributes[] = "lang=\"$lang\"";
 
@@ -1779,7 +1779,7 @@
 	} else {
 		$_file = admin_url("$file.css");
 	}
-	$_file = add_query_arg( 'version', get_bloginfo( 'version' ),  $_file );
+	$_file = add_query_arg( 'version', get_blog_info( 'version' ),  $_file );
 
 	return apply_filters( 'wp_admin_css_uri', $_file, $file );
 }
@@ -1822,7 +1822,7 @@
 	}
 
 	echo apply_filters( 'wp_admin_css', "<link rel='stylesheet' href='" . clean_url( wp_admin_css_uri( $file ) ) . "' type='text/css' />\n", $file );
-	if ( 'rtl' == get_bloginfo( 'text_direction' ) )
+	if ( 'rtl' == get_blog_info( 'text_direction' ) )
 		echo apply_filters( 'wp_admin_css', "<link rel='stylesheet' href='" . clean_url( wp_admin_css_uri( "$file-rtl" ) ) . "' type='text/css' />\n", "$file-rtl" );
 }
 
@@ -1880,25 +1880,25 @@
 function get_the_generator( $type ) {
 	switch ($type) {
 		case 'html':
-			$gen = '<meta name="generator" content="WordPress ' . get_bloginfo( 'version' ) . '">' . "\n";
+			$gen = '<meta name="generator" content="WordPress ' . get_blog_info( 'version' ) . '">' . "\n";
 			break;
 		case 'xhtml':
-			$gen = '<meta name="generator" content="WordPress ' . get_bloginfo( 'version' ) . '" />' . "\n";
+			$gen = '<meta name="generator" content="WordPress ' . get_blog_info( 'version' ) . '" />' . "\n";
 			break;
 		case 'atom':
-			$gen = '<generator uri="http://wordpress.org/" version="' . get_bloginfo_rss( 'version' ) . '">WordPress</generator>';
+			$gen = '<generator uri="http://wordpress.org/" version="' . get_blog_info_rss( 'version' ) . '">WordPress</generator>';
 			break;
 		case 'rss2':
-			$gen = '<generator>http://wordpress.org/?v=' . get_bloginfo_rss( 'version' ) . '</generator>';
+			$gen = '<generator>http://wordpress.org/?v=' . get_blog_info_rss( 'version' ) . '</generator>';
 			break;
 		case 'rdf':
-			$gen = '<admin:generatorAgent rdf:resource="http://wordpress.org/?v=' . get_bloginfo_rss( 'version' ) . '" />';
+			$gen = '<admin:generatorAgent rdf:resource="http://wordpress.org/?v=' . get_blog_info_rss( 'version' ) . '" />';
 			break;
 		case 'comment':
-			$gen = '<!-- generator="WordPress/' . get_bloginfo( 'version' ) . '" -->';
+			$gen = '<!-- generator="WordPress/' . get_blog_info( 'version' ) . '" -->';
 			break;
 		case 'export':
-			$gen = '<!-- generator="WordPress/' . get_bloginfo_rss('version') . '" created="'. date('Y-m-d H:i') . '"-->';
+			$gen = '<!-- generator="WordPress/' . get_blog_info_rss('version') . '" created="'. date('Y-m-d H:i') . '"-->';
 			break;
 	}
 	return apply_filters( "get_the_generator_{$type}", $gen, $type );
@@ -214,13 +214,13 @@
  * Display information about the blog.
  *
- * @see get_bloginfo() For possible values for the parameter.
+ * @see get_blog_info() For possible values for the parameter.
  * @since 0.71
  *